@@ -1,9 +1,10 @@
-__version__ = "0.498"
+__version__ = "0.499.2"
 from .loader import *
 from .charts import *
 from .paths import *
 from .markup import *
 from .inspector import *
+from .load_defaults import *
 from .pdf_loader import PDF
 
 try:
