@@ -1,6 +1,7 @@
 __all__ = [
     "B",
     "Blank",
+    "batchify",
     "C",
     "choose",
     "common",
@@ -29,6 +30,7 @@ __all__ = [
     "pdb",
     "plt",
     "PIL",
+    "print",
     "puttext",
     "randint",
     "rand",
@@ -44,6 +46,8 @@ __all__ = [
     "store_attr",
     "subplots",
     "sys",
+    "toss",
+    "track",
     "tqdm",
     "Tqdm",
     "trange",
@@ -107,6 +111,10 @@ import time
 from collections import defaultdict, Counter
 from copy import deepcopy as dcopy
 
+from rich.progress import track as _track
+
+track = lambda iterator, description="": _track(iterator, description=description)
+
 
 class Timer:
     def __init__(self, N):
@@ -927,3 +935,18 @@ def get(self, condition):
 def get_all(self, condition):
     sublist = self.filter(condition)
     return sublist
+
+
+def batchify(items, batch_size=32):
+    "yield `batch_size` items at a time"
+    head = 0
+    n = len(items)
+    while head < n:
+        tail = head + batch_size
+        batch = items[head:tail]
+        yield batch
+        head = tail
+
+
+def toss(frac: float, pass_=True, fail_=False):
+    return [fail_, pass_][np.random.uniform() < frac]
